==> cs_models-0.0.393-py3-none-any.whl: cs_models/resources/DrugIndication/__init__.py <==
from sqlalchemy.exc import SQLAlchemyError
from sqlalchemy.orm.exc import NoResultFound
from marshmallow import ValidationError, EXCLUDE

from cs_models.utils.utils import update_model
from ...database import db_session
from ...resources.DrugIndication.models import (
    DrugIndicationModel,
)
from .schemas import (
    DrugIndicationPatchSchema,
    DrugIndicationQueryParamsSchema,
    DrugIndicationResourceSchema,
)


schema_resource = DrugIndicationResourceSchema()
schema_params = DrugIndicationQueryParamsSchema()
schema_patch = DrugIndicationPatchSchema()


class DrugIndication(object):
    @staticmethod
    def create(params):
        """
        Args:
            params: dict(IndicationResourceSchema)

        Returns: IndicationResourceSchema

        Raises:
            ValidationError
            SQLAlchemyError
        """
        data = schema_resource.load(params, unknown=EXCLUDE)
        response = _helper_create(data)
        return response

    @staticmethod
    def read(params):
        """
        Args:
            params: dict(IndicationQueryParamsSchema)

        Returns: List<IndicationResourceSchema>

        Raises:
            ValidationError
        """
        data = schema_params.load(params, unknown=EXCLUDE)

        document_ref_query = _build_query(params=data)
        response = schema_resource.dump(
            document_ref_query, many=True).data
        return response

    @staticmethod
    def one(params):
        """
        Args:
            params: dict(IndicationQueryParamsSchema)

        Returns: IndicationResourceSchema

        Raises:
            ValidationError
        """
        data = schema_params.load(params, unknown=EXCLUDE)

        indication_query = _build_query(params=data).one()
        response = schema_resource.dump(indication_query).data
        return response

    @staticmethod
    def update(id, params):
        """

        Args:
            id: int
            params: IndicationPatchSchema

        Returns:
            IndicationResourceSchema

        Raises:
            sqlalchemy.orm.exc.NoResultFound
            sqlalchemy.orm.exc.MultipleResultsFound
            ValidationError
        """
        indication_query = db_session.query(
            DrugIndicationModel).filter_by(id=id).one()
        data = schema_patch.load(params, unknown=EXCLUDE)

        response = _helper_update(data, indication_query)
        return response

    @staticmethod
    def upsert(params):
        """
        Args:
            params: IndicationResourceSchema

        Returns:
            IndicationResourceSchema

        Raises:
            ValidationError
        """
        data = schema_resource.load(params, unknown=EXCLUDE)

        try:
            query_params = {
                'set_id': params['set_id'],
                'indication': params['indication'],
                'lowercase_indication': params['lowercase_indication'],
            }
            indication_query = _build_query(query_params).one()
            response = _helper_update(data, indication_query)
        except NoResultFound:
            response = _helper_create(data)
        return response

    @staticmethod
    def delete(id):
        """
        Args:
            id: int

        Returns: string

        Raises:
            sqlalchemy.orm.exc.NoResultFound
            sqlalchemy.orm.exc.MultipleResultsFound
            SQLAlchemyError
        """
        indication_query = db_session.query(
            DrugIndicationModel).filter_by(id=id).one()
        try:
            db_session.delete(indication_query)
            db_session.commit()
            db_session.close()
            return 'Successfully deleted'
        except SQLAlchemyError:
            db_session.rollback()
            db_session.close()
            raise


def _helper_create(data):
    new_indication = DrugIndicationModel(**data)
    try:
        db_session.add(new_indication)
        db_session.commit()
        indication_query = db_session.query(
            DrugIndicationModel).get(
            new_indication.id)
        response = schema_resource.dump(indication_query).data
        db_session.close()
        return response
    except SQLAlchemyError:
        db_session.rollback()
        db_session.close()
        raise


def _helper_update(data, indication_query):
    data['id'] = indication_query.id
    try:
        update_model(data, indication_query)
        db_session.commit()
        response = schema_resource.dump(indication_query).data
        return response
    except SQLAlchemyError:
        db_session.rollback()
        raise


def _build_query(params):
    q = db_session.query(
        DrugIndicationModel)
    if params.get('id'):
        q = q.filter_by(id=params.get('id'))
    if params.get('set_id'):
        q = q.filter_by(set_id=params.get('set_id'))
    if params.get('lowercase_indication'):
        q = q.filter_by(lowercase_indication=params.get(
            'lowercase_indication'))
    return q

==> cs_models-0.0.594-py3-none-any.whl: cs_models/resources/DrugIndication/__init__.py <==
from sqlalchemy.exc import SQLAlchemyError
from sqlalchemy.orm.exc import NoResultFound
from marshmallow import ValidationError, EXCLUDE

from cs_models.utils.utils import update_model
from ...database import db_session
from ...resources.DrugIndication.models import (
    DrugIndicationModel,
)
from .schemas import (
    DrugIndicationPatchSchema,
    DrugIndicationQueryParamsSchema,
    DrugIndicationResourceSchema,
)


schema_resource = DrugIndicationResourceSchema()
schema_params = DrugIndicationQueryParamsSchema()
schema_patch = DrugIndicationPatchSchema()


class DrugIndication(object):
    @staticmethod
    def create(params):
        """
        Args:
            params: dict(IndicationResourceSchema)

        Returns: IndicationResourceSchema

        Raises:
            ValidationError
            SQLAlchemyError
        """
        data = schema_resource.load(params, unknown=EXCLUDE)
        response = _helper_create(data)
        return response

    @staticmethod
    def read(params):
        """
        Args:
            params: dict(IndicationQueryParamsSchema)

        Returns: List<IndicationResourceSchema>

        Raises:
            ValidationError
        """
        data = schema_params.load(params, unknown=EXCLUDE)

        document_ref_query = _build_query(params=data)
        response = schema_resource.dump(
            document_ref_query, many=True)
        return response

    @staticmethod
    def one(params):
        """
        Args:
            params: dict(IndicationQueryParamsSchema)

        Returns: IndicationResourceSchema

        Raises:
            ValidationError
        """
        data = schema_params.load(params, unknown=EXCLUDE)

        indication_query = _build_query(params=data).one()
        response = schema_resource.dump(indication_query)
        return response

    @staticmethod
    def update(id, params):
        """

        Args:
            id: int
            params: IndicationPatchSchema

        Returns:
            IndicationResourceSchema

        Raises:
            sqlalchemy.orm.exc.NoResultFound
            sqlalchemy.orm.exc.MultipleResultsFound
            ValidationError
        """
        indication_query = db_session.query(
            DrugIndicationModel).filter_by(id=id).one()
        data = schema_patch.load(params, unknown=EXCLUDE)

        response = _helper_update(data, indication_query)
        return response

    @staticmethod
    def upsert(params):
        """
        Args:
            params: IndicationResourceSchema

        Returns:
            IndicationResourceSchema

        Raises:
            ValidationError
        """
        data = schema_resource.load(params, unknown=EXCLUDE)

        try:
            query_params = {
                'set_id': params['set_id'],
                'indication': params['indication'],
                'lowercase_indication': params['lowercase_indication'],
            }
            indication_query = _build_query(query_params).one()
            response = _helper_update(data, indication_query)
        except NoResultFound:
            response = _helper_create(data)
        return response

    @staticmethod
    def delete(id):
        """
        Args:
            id: int

        Returns: string

        Raises:
            sqlalchemy.orm.exc.NoResultFound
            sqlalchemy.orm.exc.MultipleResultsFound
            SQLAlchemyError
        """
        indication_query = db_session.query(
            DrugIndicationModel).filter_by(id=id).one()
        try:
            db_session.delete(indication_query)
            db_session.commit()
            db_session.close()
            return 'Successfully deleted'
        except SQLAlchemyError:
            db_session.rollback()
            db_session.close()
            raise


def _helper_create(data):
    new_indication = DrugIndicationModel(**data)
    try:
        db_session.add(new_indication)
        db_session.commit()
        indication_query = db_session.query(
            DrugIndicationModel).get(
            new_indication.id)
        response = schema_resource.dump(indication_query)
        db_session.close()
        return response
    except SQLAlchemyError:
        db_session.rollback()
        db_session.close()
        raise


def _helper_update(data, indication_query):
    data['id'] = indication_query.id
    try:
        update_model(data, indication_query)
        db_session.commit()
        response = schema_resource.dump(indication_query)
        return response
    except SQLAlchemyError:
        db_session.rollback()
        raise


def _build_query(params):
    q = db_session.query(
        DrugIndicationModel)
    if params.get('id'):
        q = q.filter_by(id=params.get('id'))
    if params.get('set_id'):
        q = q.filter_by(set_id=params.get('set_id'))
    if params.get('lowercase_indication'):
        q = q.filter_by(lowercase_indication=params.get(
            'lowercase_indication'))
    return q
